==> readmeter-3.0.0-33.jar: readmeter/sqls/readmeterinfo/PcHandInfo.sql <==
select * from (

SELECT
	uf.f_meter_base f_last_tablebase,
	uf.f_hand_date f_last_input_date,
	uf.f_orgid,
	uf.f_table_state,
	uf.f_filialeid,
	uf.f_user_id,
	uf.f_meternumber,
	uf.f_userfiles_id,
	uf.f_user_type,
	uf.f_gasproperties,
	uf.f_price_id,
	uf.f_meter_book_sort,
	u.f_userinfo_id,
	u.f_userinfo_code,
	u.f_user_name,
	u.f_user_phone,
	u.f_balance,
	u.f_user_state,
	ua.f_address,
	ua.f_residential_area,
	ua.f_building,
	ua.f_unit,
	ua.f_floor,
	ua.f_room,
	gb.f_meter_brand,
	uf.f_meter_classify,
	gm.f_meter_style,
	mb.id,
	mb.f_book_name,
	ad.f_adjustable_name,
	ad.f_adjustable_id,
	case when CHARINDEX('-',ad.f_adjustable_id)>0 then
		case when isnumeric(SUBSTRING(ad.f_adjustable_id,1,CHARINDEX('-',ad.f_adjustable_id)-1))=1 then cast(SUBSTRING(ad.f_adjustable_id,1,CHARINDEX('-',ad.f_adjustable_id)-1) as float)
		else 99999 end
    else 99999 end ad_id1,
	case when CHARINDEX('-',ad.f_adjustable_id)>0 then
	  case when isnumeric(SUBSTRING(ad.f_adjustable_id,CHARINDEX('-',ad.f_adjustable_id)+1,len(ad.f_adjustable_id))) = 1
    then cast(SUBSTRING(ad.f_adjustable_id,CHARINDEX('-',ad.f_adjustable_id)+1,len(ad.f_adjustable_id)) as float) else 99999 end else 99999
	 end ad_id2
FROM
	t_userfiles uf
	LEFT JOIN t_user_address ua ON uf.f_useraddress_id = ua.id
	LEFT JOIN t_userinfo u ON u.f_userinfo_id = uf.f_userinfo_id
	left join t_gasbrand gb on uf.f_gasbrand_id = gb.id
	left join t_gasmodel gm on uf.f_gasmodel_id=gm.id
	left join t_meter_book mb on uf.f_meter_book_num=mb.id
	left join t_area a on ua.f_residential_area_id = a.id
	LEFT JOIN t_adjustablebox ad ON uf.f_adjustable_id = ad.id
	)t
where {condition} AND  (f_meter_classify = '机表' or f_meter_classify like '%卡表' )  AND f_table_state = '正常' and f_user_state='正常'
order by f_book_name,f_meter_book_sort,ad_id1,len(ad_id2),ad_id2,id,f_address {sort}

==> readmeter-3.0.1-1.jar: readmeter/sqls/readmeterinfo/PcHandInfo.sql <==
select * from (

SELECT
	uf.f_meter_base f_last_tablebase,
	uf.f_hand_date f_last_input_date,
	uf.f_orgid,
	uf.f_table_state,
	uf.f_filialeid,
	uf.f_user_id,
	uf.f_meternumber,
	uf.f_userfiles_id,
	uf.f_user_type,
	uf.f_gasproperties,
	uf.f_price_id,
	uf.f_meter_book_sort,
	u.f_userinfo_id,
	u.f_userinfo_code,
	u.f_user_name,
	u.f_user_phone,
	u.f_balance,
	u.f_user_state,
	ua.f_address,
	ua.f_residential_area,
	ua.f_building,
	ua.f_unit,
	ua.f_floor,
	ua.f_room,
	gb.f_meter_brand,
	uf.f_meter_classify,
	gm.f_meter_style,
	mb.id,
	mb.f_book_name,
	uf.f_metertitles f_adjustable_id,
	case when CHARINDEX('-',uf.f_metertitles)>0 then
		case when isnumeric(SUBSTRING(uf.f_metertitles,1,CHARINDEX('-',uf.f_metertitles)-1))=1 then cast(SUBSTRING(uf.f_metertitles,1,CHARINDEX('-',uf.f_metertitles)-1) as float)
		else 99999 end
    else 99999 end ad_id1,
	case when CHARINDEX('-',uf.f_metertitles)>0 then
	  case when isnumeric(SUBSTRING(uf.f_metertitles,CHARINDEX('-',uf.f_metertitles)+1,len(uf.f_metertitles))) = 1
    then cast(SUBSTRING(uf.f_metertitles,CHARINDEX('-',uf.f_metertitles)+1,len(uf.f_metertitles)) as float) else 99999 end else 99999
	 end ad_id2
FROM
	t_userfiles uf
	LEFT JOIN t_user_address ua ON uf.f_useraddress_id = ua.id
	LEFT JOIN t_userinfo u ON u.f_userinfo_id = uf.f_userinfo_id
	left join t_gasbrand gb on uf.f_gasbrand_id = gb.id
	left join t_gasmodel gm on uf.f_gasmodel_id=gm.id
	left join t_meter_book mb on uf.f_meter_book_num=mb.id
	left join t_area a on ua.f_residential_area_id = a.id

	)t
where {condition} AND  (f_meter_classify = '机表' or f_meter_classify like '%卡表' )  AND f_table_state = '正常' and f_user_state='正常'
order by f_book_name,ad_id1,len(ad_id2),ad_id2,id,f_address {sort}
